# Repo for Medical Image Development Tools
```shell
Copyright IDEA Lab, School of Biomedical Engineering, ShanghaiTech. Shanghai, China

Licensed under the the GPL (General Public License);
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Repo for Medical Image Development Tools (MID)
Contact: JiamengLiu.PRC@gmail.com
```